<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>Sobre </translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doar</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Contacto</translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>Licença: </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation>Ferramenta de Captura de Imagem e Edição</translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Atalho</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation>Fazer Captura</translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation>Incluir Cursor</translation>
    </message>
    <message>
        <source>Delay</source>
        <translation>Atraso</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation>Modo de Captura</translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation>Mostrar imagem na janela de pinada</translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation>Copiar imagem para a área de transferência</translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation>Enviar Imagem</translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation>Abrir o diretório da imagem</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Salvar imagem</translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation>Esconder Janela Principal</translation>
    </message>
    <message>
        <source>Global</source>
        <translation>Global</translation>
    </message>
    <message>
        <source>When enabled will make the shortcut
available even when ksnip has no focus.</source>
        <translation>Quando ativado fará o atalho disponível
mesmo quando ksnip não tem o foco.</translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation>Configurações de Ações</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Ação</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Imagem para marca d&apos;água é necessária</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>Adicione uma imagem de marca d&apos;água em: Opções &gt; Configurações &gt; Editor &gt; Selecionar</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>Suavizar Traços</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>Quando ativado, suaviza a caneta e
o marcador após finalizar o desenho.</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>Fator de suavização</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>Incrementar o fator de suavização diminuirá
a precisão da caneta e do marcador, mas irá
torná-los mais suaves.</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>Configurações do Editor</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation>Lembre-se da ferramenta selecionada e carregue na inicialização</translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation>Mudar para ferramenta de seleção após desenhar o item</translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation>Mudança na Ferramenta atualiza todos os itens número</translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation>Desativar esta opção causa mudanças na ferramenta número
para afetar apenas novos itens, mas não os itens existentes.
Desativar esta opção permite ter números duplicados.</translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation>Cor de fundo do ecrã</translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation>Cor de fundo padrão do ecrã para a área de anotação.
Alterar a cor afeta apenas novas áreas de anotação.</translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation>Escolher o item após desenhar</translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation>Com esta opção ativa, o item fica selecionado após
ser criado, permitindo alterar as configurações.</translation>
    </message>
    <message>
        <source>Show Controls Widget</source>
        <translation>Mostrar widget de controles</translation>
    </message>
    <message>
        <source>The Controls Widget contains the Undo/Redo,
Crop, Scale, Rotate and Modify Canvas buttons.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>Capturar ecrã ao iniciar, usando o modo por omissão</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>Estilo da Aplicação</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>Define o estilo da aplicação que determina a aparência da interface gráfica.
Requer reiniciar o ksnip para aplicar as mudanças.</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>Configurações da Aplicação</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>Automaticamente copiar novas capturas para a área de transferência</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>Usar Abas</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>A mudança requer reinicialização.</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>Executar o ksnip como instância única</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>Ocultar barra de abas quando apenas uma guia for usada.</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation>Ativar esta opção permitirá que apenas uma instância do ksnip funcione,
todas as outras instâncias iniciadas após a primeira passarão os
argumentos dele para a primeira e fechar. Alterar esta opção requer
um novo início de todas as instâncias.</translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation>Lembre-se da posição da janela principal ao mover e carregar na inicialização</translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation>Ocultar abas automaticamente</translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation>Auto ocultar Docks</translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation>Na inicialização, oculte as configurações de barra de ferramentas e anotações.
A visibilidade das Docks pode ser alternada com a tecla Tab.</translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation>Redimensionar automaticamente para o conteúdo</translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation>Redimensionar automaticamente a janela principal para se ajustar a imagem.</translation>
    </message>
    <message>
        <source>Enable Debugging</source>
        <translation>Ativar depuração</translation>
    </message>
    <message>
        <source>Enables debug output written to the console.
Change requires ksnip restart to take effect.</source>
        <translation>Ativa a saída de depuração gravada no console.
A mudança requer o reinício do ksnip para ter efeito.</translation>
    </message>
    <message>
        <source>Resizing to content is delay to allow the Window Manager to receive
the new content. In case that the Main Windows is not adjusted correctly
to the new content, increasing this delay might improve the behavior.</source>
        <translation>Atraso para redimensionar conteúdo permite que o gestor de janelas receba 
um novo conteúdo, caso a janela principal não esteja ajustada corretamente
 ao novo conteúdo, aumentar esse atraso pode melhorar o comportamento.</translation>
    </message>
    <message>
        <source>Resize delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Temp Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Temp directory used for storing temporary images that are
going to be deleted after ksnip closes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Selecionar</translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>Contribuidores:</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>Tradução para Espanhol</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>Tradução para Holandês</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>Tradução para Russo</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>Tradução para Norueguês Bokmål</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>Tradução para Francês</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>Tradução para Polonês</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Suporte a Snap e Flatpak</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation>Autores:</translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>Aviso - </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>A captura %1%2%3 foi modificada.
Deseja salvá-la?</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>Desenhar uma área retangular com o rato</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>Capturar ecrã inteiro incluindo todos os monitores</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>Capturar o ecrã onde o rato está localizado</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>Capturar a janela que atualmente está com o foco</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>Capturar o que está atualmente sob o cursor do rato</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>Realizar uma captura de ecrã da última área retangular selecionada</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation>Usar o portal de captura de ecrã para fazer a captura do ecrã</translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation>Comunidade</translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation>Registo de Problemas</translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
        <translation>Se tiver dúvidas gerais, idéias ou apenas quiser falar sobre o ksnip, &lt;br/&gt; por favor entre em nosso servidor% 1 ou% 2.</translation>
    </message>
    <message>
        <source>Please use %1 to report bugs.</source>
        <translation>Por favor, use %1 para relatar bugs.</translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation>Falha ao copiar para a área de transferência</translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation>Falha ao copiar para a área de transferência como imagem codificada em base64.</translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation>Copiado para a área de transferência</translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation>Copiado para a área de transferência como imagem codificada em base64.</translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation>Apagar imagem</translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation>O item &apos;%1&apos; será apagado.
Deseja continuar?</translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donations are always welcome</source>
        <translation>Doações são sempre bem-vindas</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>Doação</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation>ksnip é um projeto de software copyleft livre sem fins lucrativos e &lt;br/&gt; ainda tem alguns custos que precisam ser cobertos, &lt;br/&gt; como custos de domínio ou custos de hardware para suporte de plataforma cruzada.</translation>
    </message>
    <message>
        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
        <translation>Se quiser ajudar ou apenas apreciar o trabalho que está sendo feito &lt;br/&gt; oferecendo uma cerveja ou café aos programadores, pode fazer isso% 1aqui% 2.</translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor?</source>
        <translation>Tornar-se um patrocinador do GitHub?</translation>
    </message>
    <message>
        <source>Also possible, %1here%2.</source>
        <translation>Também é possível, %1aqui%2.</translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation>Adicionar novas ações a pressionar o botão da guia &apos;Adicionar&apos;.</translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation>Área retangular</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation>Última Área Retangular</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation>Ecrã cheio (Todos os monitores)</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation>Ecrã atual</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation>Janela Ativa</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation>Janela Sob o Cursor</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation>Portal de captura do ecrã</translation>
    </message>
</context>
<context>
    <name>FtpUploaderSettings</name>
    <message>
        <source>Force anonymous upload.</source>
        <translation>Forçar envio anônimo.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de utilizador</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>Enviador FTP</translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>Upload bem sucedido</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation>Não foi possível salvar a imagem temporária para upload.</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation>Não foi possível iniciar o processo, verifique o caminho e as permissões.</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>Processo travado</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>O tempo limite do processo expirou.</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation>Erro no processo de leitura.</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation>Erro no processo de gravação.</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation>Erro na Web, verifique a saída do console.</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>Falha no upload</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation>Script escrito para StdErr.</translation>
    </message>
    <message>
        <source>FTP Upload finished successfully.</source>
        <translation>FTP Envio concluído com sucesso.</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>Erro desconhecido.</translation>
    </message>
    <message>
        <source>Connection Error.</source>
        <translation>Erro de conexão.</translation>
    </message>
    <message>
        <source>Permission Error.</source>
        <translation>Erro de permissão.</translation>
    </message>
    <message>
        <source>Upload script %1  finished successfully.</source>
        <translation>O script de envio %1 foi concluído com sucesso.</translation>
    </message>
    <message>
        <source>Uploaded to %1</source>
        <translation>Enviado para %1</translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>Ativar as teclas de atalho globais</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>Captura de Área retangular</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>Captura do ecrã cheio</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>Captura do ecrã atual</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>Captura da Janela ativa</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>Captura da Janela sob o rato</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>Teclas de Atalho Globais</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>Captura da Última área retangular</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation>Capturar utilizando Portal</translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation>As HotKeys são atualmente suportadas apenas em Windows e X11.
Desativar esta opção também faz com que os atalhos de ação sejam apenas ksnip.</translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>Capturar o cursor do rato na captura de ecrã</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>O cursor do rato estará visível nas
capturas de ecrã.</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Captura de Imagem</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation>Implementações genéricas do Wayland que utilizam o
XDG-DESKTOP-PORTAL lidam com o dimensionamento
do ecrã de forma diferente. Ativar esta opção irá
determinar a escala atual do ecrã e aplicar isso à captura
do ecrã no ksnip.</translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation>GNOME e KDE Plasma suportam as próprias capturas
do ecrã do Wayland e Generic XDG-DESKTOP-PORTAL.
Ativar esta opção irá forçar o KDE Plasma e o GNOME a 
usar as capturas do XDG-DESKTOP-PORTAL. A alteração 
desta opção exige que o ksnip seja reiniciado.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation>Exibir janela principal após capturar o ecrã</translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation>Ocultar a janela principal durante a captura do ecrã</translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation>Ocultar a janela principal ao capturar uma nova imagem.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation>Mostrar a Janela Principal após uma nova captura
quando a Janela Principal foi escondida ou minimizada.</translation>
    </message>
    <message>
        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
        <translation>Forçar Wayland genérico (xdg-desktop-portal) capturar de ecrã</translation>
    </message>
    <message>
        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
        <translation>Escalar Wayland genérico (xdg-desktop-portal) para capturas de ecrã</translation>
    </message>
    <message>
        <source>Implicit capture delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This delay is used when no delay was selected in
the UI, it allows ksnip to hide before taking
a screenshot. This value is not applied when
ksnip was already minimized. Reducing this value
can have the effect that ksnip&apos;s main window is
visible on the screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Histórico do Imgur</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>Registro de Data e Hora</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Link</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Apagar Link</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation>Upload para imgur.com concluído!</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>Novo token recebido , tentando fazer o upload novamente…</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>O token Imgur expirou, solicitando novo token…</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>Forçar upload anônimo</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>Sempre copiar o link Imgur para a área de transferência</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>Client ID</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>Segredo do cliente</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>Digite imgur Pin, que será trocado por um token.</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>Obter PIN</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>Obter Token</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Histórico do Imgur</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Histórico do Imgur</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de utilizador</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Token Imgur.com atualizado com sucesso.</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Erro na atualização do token Imgur.com.</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>Aguardando imgur.com…</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>Depois do upload, abrir link do Imgur no navegador padrão</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>Link direto para a imagem</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation>Url base:</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation>Url base que será usado para comunicação com Imgur.
Mudança requer reinicialização.</translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation>Limpar Token</translation>
    </message>
    <message>
        <source>Upload title:</source>
        <translation>Ficheiro do envio</translation>
    </message>
    <message>
        <source>Upload description:</source>
        <translation>Descrição do envio</translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation>Incapaz de abrir a imagem</translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation>Incapaz de abrir a imagem do caminho %1</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>Atraso em segundos entre o acionamento
e captura de ecrã.</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>Gravar captura de ecrã para o sistema de ficheiros</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>Copiar captura de ecrã para a área de transferência</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desfazer</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Refazer</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Recortar</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>Recortar captura de ecrã</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unsaved</source>
        <translation>Não salvo</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>Abrir caixa de diálogo da impressão e fornecer as opções de impressão</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>Visualizar impressão</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>Abrir caixa de diálogo Visualizar impressão, onde a orientação da imagem pode ser alterada</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Redimensionar</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Opções</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Aj&amp;uda</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>Adicionar marca d&apos;água</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>Adicionar marca d&apos;água à imagem capturada. Várias marcas d&apos;água podem ser adicionadas.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Arquivo</translation>
    </message>
    <message>
        <source>Unable to show image</source>
        <translation>Não foi possível exibir a imagem</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Salvar como...</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation>Colar incorporado</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Fixar</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation>Fixar captura de ecrã em primeiro plano na janela sem moldura</translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation>Nenhuma imagem fornecida, mas uma era esperada.</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Copiar caminho</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Abrir diretório</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Exibir</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation>Abrir Imagens</translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation>Exibir Docks</translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation>Ocultar Docks</translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation>Copiar como URI de dados</translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation>Aberto &amp;Recente</translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation>Modificar fundo do ecrã</translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation>Carregar triggerCapture para fonte externa</translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation>Copiar o triggerCaptura para a área de transferência do sistema</translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation>Escala de Imagem</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Rotacionar</translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation>Rotacionar Imagem</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Ações</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Ficheiros de imagem</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>Gravar tudo</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation>Fechar janela</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OCR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Salvar como</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Abrir Diretório</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Copiar caminho</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>Gravar tudo</translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>Imagem</translation>
    </message>
</context>
<context>
    <name>OcrWindowCreator</name>
    <message>
        <source>OCR Window %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Fechar Outros</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Fechar Todos</translation>
    </message>
</context>
<context>
    <name>PinWindowCreator</name>
    <message>
        <source>OCR Window %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PluginsSettings</name>
    <message>
        <source>Search Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <source>The directory where the plugins are located.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Selecionar</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <source>Detect</source>
        <translation>Detetar</translation>
    </message>
    <message>
        <source>Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plugin location</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProcessIndicator</name>
    <message>
        <source>Processing</source>
        <translation>A processar</translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation>Imagem Renomeada</translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation>Falhou ao renomear imagem</translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation>Renomear imagem</translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation>Novo nome do ficheiro:</translation>
    </message>
    <message>
        <source>Successfully renamed image to %1</source>
        <translation>Imagem renomeada com sucesso para %1</translation>
    </message>
    <message>
        <source>Failed to rename image to %1</source>
        <translation>Falha ao mudar o nome da imagem para %1</translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>Salvar como</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Todos os ficheiros</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>Imagem salva</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>Falha ao salvar imagem</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Ficheiros de imagem</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Salvo em %1</translation>
    </message>
    <message>
        <source>Failed to save image to %1</source>
        <translation>Falha ao gravar a imagem em %1</translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation>Automaticamente salvar novas capturas para o diretório padrão</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation>Avisar para salvar antes de descartar um trabalho não salvo</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation>Lembrar o último diretório onde os arquivos foram salvos</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation>Quando ativado, substituirá o diretório de &quot;salvamento&quot; armazenado nas configurações
para o diretório mais recente onde foi salvo, isso para cada vez que usar o comando salvar.</translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation>Local e nome do ficheiro para gravar a captura</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation>Os formatos suportados são JPG, PNG e BMP. Se nenhum formato for fornecido, o PNG será usado como padrão.
O nome do arquivo pode conter os seguintes curingas:
- $Y, $M, $D para data, $h, $m, $s para hora ou $T para hora no formato hhmmss.
- # múltiplos consecutivos para contador. #### resultará em 0001, a próxima captura será 0002.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Selecionar</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation>Configurações para Salvar arquivos</translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation>Local para salvar a captura</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Fator</translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>Qualidade para salvar</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation>Indique 0 para obter pequenos ficheiros compactados, 100 para grandes ficheiros não compactados.
Nem todos os formatos de imagem têm suporte a todos os intervalos, o JPEG suporta.</translation>
    </message>
    <message>
        <source>Overwrite file with same name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation>Copiar saída do script para a área de transferência</translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>Script:</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation>Caminho para o script que será chamado para upload. Durante o upload, o script será chamado
com o caminho para um ficheiro png temporário como um único argumento.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Selecionar</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Script de Uploader</translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation>Selecione o Script para Upload</translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation>Parar quando o script de upload é gravado no StdErr</translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation>Marca o upload como malsucedido quando o script grava no StdErr.
Sem essa configuração, os erros no script não serão notados.</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation>Expressão RegEx. Apenas copie para a área de transferência aquilo que corresponda à expressão RegEx.
Quando omitido, tudo é copiado.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Aplicação</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Captura de Imagem</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Serviço Imgur</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>Editor</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>Teclas de Atalho</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Enviador</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Script de Uploader</translation>
    </message>
    <message>
        <source>Saver</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation>Adesivos</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Área Retangular</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation>Ícone da bandeja</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>Marca d&apos;água</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Ações</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>Enviador de FTP</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search Settings...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation>Redimensione o retângulo selecionado a usar as alças ou mova-o a arrastar a seleção.</translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation>Use as setas para mover a seleção.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation>Use as seta enquanto pressiona CTRL para mover a alça superior esquerda.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation>Use as teclas de seta enquanto pressiona ALT para mover a alça inferior direita.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Esta mensagem pode ser desativada nas configurações.</translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or mouse double-click anywhere.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort by pressing ESC.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation>Clique e arraste para selecionar uma área retangular ou pressione ESC para sair.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation>Mantenha CTRL pressionado para redimensionar a seleção após selecionar.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation>Mantenha CTRL pressionado para evitar o redimensionamento após selecionar.</translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation>A operação será cancelada após 60 segundos quando nenhuma seleção for feita.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Esta mensagem pode ser desativada nas configurações.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation>Congelar imagem ao capturar área retangular</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation>Quando ativado irá congelar o fundo enquanto
a selecionar uma área retangular. Também muda
o comportamento de capturas do ecrã atrasadas, com esta
opção ativada o atraso acontece antes da
área retangular ser exibida e com a opção desativada
o atraso acontece depois que a área retangular é exibida.
Este recurso está sempre desativado para Wayland e sempre
ativado para MacOs.</translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation>Exibir lupa ao capturar área retangular</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation>Exibir uma lupa que mostra zoom
na imagem de fundo. Esta opção só funciona
com &apos;Congelar imagem ao capturar área retangular&apos; ativada.</translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation>Exibir réguas ao capturar área retangular</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation>Uma linha horizontal e vertical será exibida
antes de iniciar a captura de uma área retangular.</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation>Exibir posição e tamanho ao capturar área retangular</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation>Quando o botão esquerdo do rato não é pressionado a posição
é exibida, quando o botão do rato é pressionado,
o tamanho da área selecionada é exibido à esquerda
e acima da área capturada.</translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation>Permitir redimensionamento da seleção da área retangular por padrão</translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation>Quando ativado, após selecionar uma área
retangular, permite redimensionar a seleção. Quando
realizado o redimensionamento a seleção pode ser confirmada
a pressionar Enter.</translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation>Mostrar texto de informação para área retangular</translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation>Cor do cursor ao capturar área retangular</translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation>Define a cor do cursor da área retangular.</translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation>Espessura do cursor ao capturar área retangular</translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation>Define a espessura do cursor da área retangular.</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Área Retangular</translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation>Cor das bordas da área de recorte</translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation>Define a cor de todos as bordas
na área de retangular.</translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation>Transparência da área retangular</translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation>Alfa para região não selecionada na área retangular.
O número menor é mais transparente.</translation>
    </message>
    <message>
        <source>Enable Snipping Area offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will apply the configured
offset to the Snipping Area position which
is required when the position is not
correctly calculated. This is sometimes
required with screen scaling enabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>Z</translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation>Subir</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Descer</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation>Usar adesivos padrão</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation>Configurações de Adesivos</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation>Ficheiros de imagem vetorial (*.svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation>Adicionar adesivos</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>Exibir Editor</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation>Usar ícone da bandeja</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation>Quando ativado, adiciona um ícone de bandeja na barra de tarefas, se o gestor de janelas do SO oferecer suporte.
A mudança requer reinicialização.</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation>Minimizar para a Bandeja</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation>Iniciar Minimizado na Bandeja</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation>Fechar para a Bandeja</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation>Exibir Editor</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Capturar</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation>Ação padrão do ícone da bandeja</translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation>Ação padrão que é disparada a clicar com o botão esquerdo do rato no ícone da bandeja.</translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation>Configurações do ícone da bandeja</translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation>Usar o serviço de notificação específico da plataforma</translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation>Quando ativado, tentará usar o serviço de notificação específico da plataforma,
quando tal existir. A mudança requer reinicialização para ter efeito.</translation>
    </message>
    <message>
        <source>Display Tray Icon notifications</source>
        <translation>Exibir notificações do ícone da bandeja</translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>Selecione uma imagem</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Ficheiros de imagem</translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation>Script de Upload Requerido</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation>Adicione um script de upload em Opções&gt; Configurações&gt; Script de Uploader</translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation>Capturar Upload</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation>Você está prestes a enviar a imagem para um destino externo. Deseja continuar?</translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation>Confirmar antes de fazer o upload</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation>Tipo de Uploader:</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>Script</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Enviador</translation>
    </message>
    <message>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <source>Build</source>
        <translation>Compilação</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Utilizando:</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation>Imagem de marca d&apos;água</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Atualizar</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation>Girar marca d&apos;água</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation>Quando ativado, a marca d&apos;água será adicionada com rotação de 45º</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation>Configurações de Marca d&apos;água</translation>
    </message>
</context>
</TS>
